@@ -3,6 +3,11 @@
 //! [1]: https://tools.ietf.org/html/rfc4503#section-2.3
 
 #![no_std]
+#![doc(
+    html_logo_url = "https://raw.githubusercontent.com/RustCrypto/media/8f1a9894/logo.svg",
+    html_favicon_url = "https://raw.githubusercontent.com/RustCrypto/media/8f1a9894/logo.svg",
+    html_root_url = "https://docs.rs/rabbit/0.3.1"
+)]
 #![deny(unsafe_code)]
 #![warn(missing_docs, rust_2018_idioms)]
 
